==> moodle-1.5-mysql.tgz: moodle/lang/pt_br/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.4.1 (2004083101)


$string['addanewdiscussion'] = 'Adicionar um novo tpico de discusso';
$string['addanewtopic'] = 'Adicionar um novo tpico';
$string['allowchoice'] = 'Todos podem escolher';
$string['allowdiscussions'] = 'Um $a pode enviar mensagens a este frum?';
$string['allowratings'] = 'Permitir a avaliao das mensagens?';
$string['allowsdiscussions'] = 'Neste frum todos os participantes podem iniciar novas discusses.';
$string['anyfile'] = 'Qualquer arquivo';
$string['attachment'] = 'Anexo';
$string['bynameondate'] = 'por $a->name - $a->date';
$string['configdisplaymode'] = 'Modalidade de visualizao das discusses predefinida, se uma outra no for configurada.';
$string['configenablerssfeeds'] = 'Esta opo ativa a possibilidade de gerar alimentadores RSS nos fruns.  necessrio configurar cada frum para que sejam gerados os alimentadores correspondentes.';
$string['configlongpost'] = 'Todas as mensagens maiores que esta dimenso (sem contar o html) so consideradas longas.';
$string['configmanydiscussions'] = 'Nmero mximo de discusses mostrado em um frum, por pgina.';
$string['configmaxbytes'] = 'Tamanho mximo predefinido dos anexos de todos os fruns do site (sujeito aos limites dos cursos e outras configuraes locais)';
$string['configreplytouser'] = 'Quando as mensagens dos fruns so enviadas aos usurios via email devem conter o endereo do autor para que seja possvel responder via email diretamente a ele sem passar pelo frum? Mesmo quando a opo escolhida for \"sim\" os usurios tero a possibilidade de mudar o perfil pessoal deles para manter o endereo de email escondido.';
$string['configshortpost'] = 'Todas as mensagens menores que esta dimenso (sem contar o html) so consideradas curtas.';
$string['couldnotadd'] = 'No foi possvel publicar a sua mensagem. Infelizmente a causa do erro no foi identificada.';
$string['couldnotdeleteratings'] = 'No  possvel apagar esta mensagem porque j foi avaliada.';
$string['couldnotdeletereplies'] = 'No  possvel apagar esta mensagem porque j existem respostas.';
$string['couldnotupdate'] = 'No foi possvel atualizar a sua mensagem. Infelizmente a causa do erro no foi identificada.';
$string['delete'] = 'Apagar';
$string['deleteddiscussion'] = 'A discusso foi apagada';
$string['deletedpost'] = 'A mensagem foi apagada';
$string['deletesure'] = 'Voc tem certeza que quer apagar esta mensagem?';
$string['digestmailheader'] = 'Este  o digest dirio das novas mensagens dos fruns de $a->sitename. Voc pode mudar as suas preferncias em relao s cpias das mensagens do frum recebidas via email na seguinte pgina do site $a->userprefs.';
$string['digestmailprefs'] = 'O seu perfil';
$string['digestmailsubject'] = '$a: digest das mensagens do frum';
$string['digestsentusers'] = 'Digests enviados a $a usurios.';
$string['discussion'] = 'Tpico';
$string['discussionmoved'] = 'Esta discusso foi transferida para \'$a\'.';
$string['discussionname'] = 'Ttulo';
$string['discussions'] = 'Tpicos';
$string['discussionsstartedby'] = 'Discusses iniciadas por $a';
$string['discussionsstartedbyrecent'] = 'Discusses iniciadas recentemente por $a';
$string['discussthistopic'] = 'Discutir este tpico';
$string['eachuserforum'] = 'Cada usurio inicia apenas UM NOVO tpico';
$string['edit'] = 'Editar';
$string['editing'] = 'Edio';
$string['emptymessage'] = 'A sua mensagem no foi enviada. Normalmente isto acontece quando a mensagem ou o campo \"assunto\" esto em branco ou quando o anexo  grande demais. ';
$string['everyonecanchoose'] = 'Todos podem fazer assinatura';
$string['everyoneissubscribed'] = 'Todos so assinantes deste frum';
$string['existingsubscribers'] = 'Assinantes';
$string['forcesubscribe'] = 'Obrigar  todos a serem assinantes';
$string['forcesubscribeq'] = 'Obrigar  todos a serem assinantes?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'Introduo ao Frum';
$string['forumname'] = 'Nome do Frum';
$string['forums'] = 'Fruns';
$string['forumtype'] = 'Tipo de Frum';
$string['generalforum'] = 'Frum geral';
$string['generalforums'] = 'Fruns gerais';
$string['inforum'] = 'em $a';
$string['intronews'] = 'Notcias e avisos';
$string['introsocial'] = 'Um frum para conversar sobre tudo o que voc quiser';
$string['introteacher'] = 'Um frum reservado aos tutores';
$string['lastpost'] = 'ltima mensagem';
$string['learningforums'] = 'Fruns para atividades de aprendizagem';
$string['maxattachmentsize'] = 'Dimenso mxima do anexo';
$string['maxtimehaspassed'] = 'Sinto muito, mas o prazo para editar este tpico ($a)terminou!';
$string['message'] = 'Mensagem';
$string['modeflatnewestfirst'] = 'Mostrar respostas comeando pela mais recente';
$string['modeflatoldestfirst'] = 'Mostrar respostas comeando pela mais antiga';
$string['modenested'] = 'Mostrar respostas aninhadas';
$string['modethreaded'] = 'Listar respostas';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Fruns';
$string['more'] = 'mais';
$string['movethisdiscussionto'] = 'Transfira esta discusso para ...';
$string['namenews'] = 'Frum de notcias';
$string['namesocial'] = 'Frum social';
$string['nameteacher'] = 'Frum dos tutores';
$string['newforumposts'] = 'Novas mensagens no frum';
$string['nodiscussions'] = 'Ainda no h nenhum tpico de discusso neste frum';
$string['noguestpost'] = 'Os visitantes no podem enviar mensagens a este frum';
$string['nomorepostscontaining'] = 'No foram encontradas outras mensagens que contenham \'$a\' ';
$string['nonews'] = 'Nenhuma notcia publicada';
$string['noposts'] = 'Nenhuma mensagem';
$string['nopostscontaining'] = 'No foi encontrada nenhuma mensagem com \'$a\' ';
$string['nosubscribers'] = 'Este frum no tem nenhum assinante';
$string['notingroup'] = 'Sinto muito mas voc precisa ser membro de um grupo para acessar este frum';
$string['nownotsubscribed'] = '$a->name no receber cpias de \'$a->forum\' pelo correio eletrnico.';
$string['nowsubscribed'] = '$a->name receber cpias de \'$a->forum\' via Email';
$string['numposts'] = '$a mensagens';
$string['olderdiscussions'] = 'Discusses mais antigas';
$string['openmode0'] = 'Nenhuma discusso, nenhuma resposta';
$string['openmode1'] = 'Nenhuma discusso, mas so permitidas respostas';
$string['openmode2'] = 'So permitidas discusses e respostas';
$string['parent'] = 'Mostrar principal';
$string['parentofthispost'] = 'Mensagem original';
$string['postadded'] = 'A sua mensagem foi enviada com sucesso.<br />Voc tem $a para fazer alteraes.';
$string['postincontext'] = 'Veja esta mensagem em seu contexto';
$string['postmailinfo'] = 'Esta  a cpia de uma mensagem enviada ao frum do website $a. 
Clique o link abaixo para consultar as mensagens no site e participar das discusses:';
$string['postrating1'] = 'Mostra sobretudo saber DESTACADO';
$string['postrating2'] = 'Igualmente DESTACADO e CONECTADO';
$string['postrating3'] = 'Mostra sobretudo saber CONECTADO';
$string['posts'] = 'Mensagens';
$string['posttoforum'] = 'Enviar mensagem ao frum';
$string['postupdated'] = 'A sua mensagem foi atualizada';
$string['potentialsubscribers'] = 'Potenciais assinantes';
$string['processingdigest'] = 'Processando digest para o usurio $a';
$string['processingpost'] = 'Processando mensagem $a';
$string['prune'] = 'Interromper';
$string['prunedpost'] = 'Foi criada uma nova discusso com esta mensagem inicial';
$string['pruneheading'] = 'Interromper a mensagem e mover para uma nova discusso';
$string['rate'] = 'Avaliar';
$string['rating'] = 'Avaliao';
$string['ratingeveryone'] = 'Todos podem avaliar as mensagens';
$string['ratingno'] = 'Nenhuma avaliao';
$string['ratingonlyteachers'] = 'Apenas o $a pode avaliar as mensagens';
$string['ratingpublic'] = '$a podem ver as avaliaes de todos';
$string['ratingpublicnot'] = '$a podem ver apenas as suas avaliaes';
$string['ratings'] = 'Avaliaes';
$string['ratingssaved'] = 'Avaliaes gravadas';
$string['ratingsuse'] = 'Usar avaliaes';
$string['ratingtime'] = 'Permitir avaliao apenas das mensagens compreendidas neste arco de tempo:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Leia o resto deste tpico';
$string['replies'] = 'Comentrios';
$string['repliesmany'] = '$a respostas at agora';
$string['repliesone'] = '$a resposta at agora';
$string['reply'] = 'Responder';
$string['replyforum'] = 'Responder ao frum';
$string['rsssubscriberssdiscussions'] = 'Mostrar RSS de \'$a\' discusses';
$string['rsssubscriberssposts'] = 'Mostrar RSS de \'$a\' mensagens';
$string['search'] = 'Buscar';
$string['searchforums'] = 'Buscar no frum';
$string['searcholderposts'] = 'Buscar nas mensagens mais antigas...';
$string['searchresults'] = 'Resultados da busca';
$string['sendinratings'] = 'Enviar as minhas avaliaes recentes';
$string['showsubscribers'] = 'Mostrar assinantes';
$string['singleforum'] = 'Uma nica discusso simples';
$string['startedby'] = 'Autor';
$string['subject'] = 'Assunto';
$string['subscribe'] = 'Receber as mensagens via email';
$string['subscribeall'] = 'Inscrever todos os participantes neste frum';
$string['subscribed'] = 'Assinante';
$string['subscribenone'] = 'Cancelar inscrio de todos os participantes deste frum';
$string['subscribers'] = 'Assinantes';
$string['subscribersto'] = 'Assinantes de \'$a\'';
$string['subscribestart'] = 'Me mande cpias das mensagens deste frum via Email';
$string['subscribestop'] = 'No quero receber cpias das mensagens deste frum via email';
$string['subscription'] = 'Assinatura';
$string['subscriptions'] = 'Assinaturas';
$string['unsubscribe'] = 'Suspender o recebimento de mensagens deste frum via email';
$string['unsubscribed'] = 'Cancelado o recebimento de cpias das mensagens via email ';
$string['unsubscribeshort'] = 'Cancelar assinatura';
$string['yesforever'] = 'Sim, sempre';
$string['yesinitially'] = 'Sim, inicialmente';
$string['youratedthis'] = 'Voc avaliou este';
$string['yournewtopic'] = 'Novo tpico de discusso';
$string['yourreply'] = 'A sua resposta';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/pt_br/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.5 + (2005060201)


$string['addanewdiscussion'] = 'Adicionar um novo tpico de discusso';
$string['addanewtopic'] = 'Adicionar um novo tpico';
$string['advancedsearch'] = 'Busca avanada';
$string['allforums'] = 'Todos os fruns';
$string['allowchoice'] = 'Todos podem escolher';
$string['allowdiscussions'] = 'Um $a pode enviar mensagens a este frum?';
$string['allowratings'] = 'Permitir a avaliao das mensagens?';
$string['allowsdiscussions'] = 'Neste frum todos os participantes podem iniciar novas discusses.';
$string['anyfile'] = 'Qualquer arquivo';
$string['attachment'] = 'Anexo';
$string['bynameondate'] = 'por $a->name - $a->date';
$string['configcleanreadtime'] = 'Hora do dia em que as mensagens antigas sero apagadas da tabela \'lidas\'.';
$string['configdisplaymode'] = 'Modalidade de visualizao das discusses predefinida, se uma outra no for configurada.';
$string['configenablerssfeeds'] = 'Esta opo ativa a possibilidade de gerar alimentadores RSS nos fruns.  necessrio configurar cada frum para que sejam gerados os alimentadores correspondentes.';
$string['configlongpost'] = 'Todas as mensagens maiores que esta dimenso (sem contar o html) so consideradas longas.';
$string['configmanydiscussions'] = 'Nmero mximo de discusses mostrado em um frum, por pgina.';
$string['configmaxbytes'] = 'Tamanho mximo predefinido dos anexos de todos os fruns do site (sujeito aos limites dos cursos e outras configuraes locais)';
$string['configoldpostdays'] = 'Nmero de dias passados antes que qualquer mensagem seja considerada lida.';
$string['configreplytouser'] = 'Quando as mensagens dos fruns so enviadas aos usurios via email devem conter o endereo do autor para que seja possvel responder via email diretamente a ele sem passar pelo frum? Mesmo quando a opo escolhida for \"sim\" os usurios tero a possibilidade de mudar o perfil pessoal deles para manter o endereo de email escondido.';
$string['configshortpost'] = 'Todas as mensagens menores que esta dimenso (sem contar o html) so consideradas curtas.';
$string['configtrackreadposts'] = 'Escolha \'sim\' se voc quiser monitorar as mensagens linas/no lidas de cada usurio';
$string['configusermarksread'] = 'Se \'sim\',o usurio ter que marcar as mensagens lidas manualmente. Se \'no\', a mensagem acessada ser marcada automaticamente.';
$string['couldnotadd'] = 'No foi possvel publicar a sua mensagem. Infelizmente a causa do erro no foi identificada.';
$string['couldnotdeleteratings'] = 'No  possvel apagar esta mensagem porque j foi avaliada.';
$string['couldnotdeletereplies'] = 'No  possvel apagar esta mensagem porque j existem respostas.';
$string['couldnotupdate'] = 'No foi possvel atualizar a sua mensagem. Infelizmente a causa do erro no foi identificada.';
$string['delete'] = 'Apagar';
$string['deleteddiscussion'] = 'A discusso foi apagada';
$string['deletedpost'] = 'A mensagem foi apagada';
$string['deletedposts'] = 'Estas mensagens foram canceladas';
$string['deletesure'] = 'Voc tem certeza que quer apagar esta mensagem?';
$string['deletesureplural'] = 'Tem certeza que quer cancelar esta mensagem e todas as respostas? ($a mensagens)';
$string['digestmailheader'] = 'Este  o digest dirio das novas mensagens dos fruns de $a->sitename. Voc pode mudar as suas preferncias em relao s cpias das mensagens do frum recebidas via email na seguinte pgina do site $a->userprefs.';
$string['digestmailprefs'] = 'O seu perfil';
$string['digestmailsubject'] = '$a: digest das mensagens do frum';
$string['digestsentusers'] = 'Digests enviados a $a usurios.';
$string['discussion'] = 'Tpico';
$string['discussionmoved'] = 'Esta discusso foi transferida para \'$a\'.';
$string['discussionname'] = 'Ttulo';
$string['discussions'] = 'Tpicos';
$string['discussionsstartedby'] = 'Discusses iniciadas por $a';
$string['discussionsstartedbyrecent'] = 'Discusses iniciadas recentemente por $a';
$string['discussthistopic'] = 'Discutir este tpico';
$string['eachuserforum'] = 'Cada usurio inicia apenas UM NOVO tpico';
$string['edit'] = 'Editar';
$string['editedby'] = 'Editado por $a->name - $a->date';
$string['editing'] = 'Edio';
$string['emptymessage'] = 'A sua mensagem no foi enviada. Normalmente isto acontece quando a mensagem ou o campo \"assunto\" esto em branco ou quando o anexo  grande demais. ';
$string['everyonecanchoose'] = 'Todos podem fazer assinatura';
$string['everyoneissubscribed'] = 'Todos so assinantes deste frum';
$string['existingsubscribers'] = 'Assinantes';
$string['forcesubscribe'] = 'Obrigar  todos a serem assinantes';
$string['forcesubscribeq'] = 'Obrigar  todos a serem assinantes?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'Introduo ao Frum';
$string['forumname'] = 'Nome do Frum';
$string['forumposts'] = 'Mensagens do frum';
$string['forums'] = 'Fruns';
$string['forumtype'] = 'Tipo de Frum';
$string['generalforum'] = 'Frum geral';
$string['generalforums'] = 'Fruns gerais';
$string['inforum'] = 'em $a';
$string['intronews'] = 'Notcias e avisos';
$string['introsocial'] = 'Um frum para conversar sobre tudo o que voc quiser';
$string['introteacher'] = 'Um frum reservado aos tutores';
$string['lastpost'] = 'ltima mensagem';
$string['learningforums'] = 'Fruns para atividades de aprendizagem';
$string['markalldread'] = 'Marcar todas as mensagens desta discusso como lidas';
$string['markallread'] = 'Marcar todas as mensagens deste frum como lidas';
$string['markread'] = 'Marcar como lida';
$string['markreadbutton'] = 'Marcar como<br />lida';
$string['markunread'] = 'Marcar como no lida';
$string['markunreadbutton'] = 'Marcar como<br />no lida';
$string['maxattachmentsize'] = 'Dimenso mxima do anexo';
$string['maxtimehaspassed'] = 'Sinto muito, mas o prazo para editar este tpico ($a)terminou!';
$string['message'] = 'Mensagem';
$string['missingsearchterms'] = 'Os seguintes termos da busca se encontram apenas no cdigo HTML desta mensagem:';
$string['modeflatnewestfirst'] = 'Mostrar respostas comeando pela mais recente';
$string['modeflatoldestfirst'] = 'Mostrar respostas comeando pela mais antiga';
$string['modenested'] = 'Mostrar respostas aninhadas';
$string['modethreaded'] = 'Listar respostas';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Fruns';
$string['more'] = 'mais';
$string['movethisdiscussionto'] = 'Transfira esta discusso para ...';
$string['namenews'] = 'Frum de notcias';
$string['namesocial'] = 'Frum social';
$string['nameteacher'] = 'Frum dos tutores';
$string['newforumposts'] = 'Novas mensagens no frum';
$string['nodiscussions'] = 'Ainda no h nenhum tpico de discusso neste frum';
$string['noguestpost'] = 'Os visitantes no podem enviar mensagens a este frum';
$string['noguestsubscribe'] = 'Sinto muito, os visitantes no podem fazer a assinatura do frum para receber cpias das mensagens por email.';
$string['noguesttracking'] = 'Sinto muito, os visitantes no podem definir opes de monitoragem.';
$string['nomorepostscontaining'] = 'No foram encontradas outras mensagens que contenham \'$a\' ';
$string['nonews'] = 'Nenhuma notcia publicada';
$string['noposts'] = 'Nenhuma mensagem';
$string['nopostscontaining'] = 'No foi encontrada nenhuma mensagem com \'$a\' ';
$string['nosubscribers'] = 'Este frum no tem nenhum assinante';
$string['notingroup'] = 'Sinto muito mas voc precisa ser membro de um grupo para acessar este frum';
$string['notrackforum'] = 'No monitorar mensagens no lidas';
$string['nownotsubscribed'] = '$a->name no receber cpias de \'$a->forum\' pelo correio eletrnico.';
$string['nownottracking'] = '$a->name no est mais monitorando \'$a->forum\'.';
$string['nowsubscribed'] = '$a->name receber cpias de \'$a->forum\' via Email';
$string['nowtracking'] = '$a->name est monitorando \'$a->forum\'.';
$string['numposts'] = '$a mensagens';
$string['olderdiscussions'] = 'Discusses mais antigas';
$string['oldertopics'] = 'Tpicos antigos';
$string['openmode0'] = 'No  permitido iniciar novas discusses, nem enviar respostas';
$string['openmode1'] = 'No  permitido iniciar novas discusses, mas so permitidas respostas';
$string['openmode2'] = ' permitido iniciar novas discusses e enviar respostas';
$string['parent'] = 'Mostrar principal';
$string['parentofthispost'] = 'Mensagem original';
$string['postadded'] = 'A sua mensagem foi enviada com sucesso.<br />Voc tem $a para fazer alteraes.';
$string['postincontext'] = 'Veja esta mensagem em seu contexto';
$string['postmailinfo'] = 'Esta  a cpia de uma mensagem enviada ao frum do website $a. 
Clique o link abaixo para consultar as mensagens no site e participar das discusses:';
$string['postrating1'] = 'Mostra sobretudo saber DESTACADO';
$string['postrating2'] = 'Igualmente DESTACADO e CONECTADO';
$string['postrating3'] = 'Mostra sobretudo saber CONECTADO';
$string['posts'] = 'Mensagens';
$string['posttoforum'] = 'Enviar mensagem ao frum';
$string['postupdated'] = 'A sua mensagem foi atualizada';
$string['potentialsubscribers'] = 'Potenciais assinantes';
$string['processingdigest'] = 'Processando digest para o usurio $a';
$string['processingpost'] = 'Processando mensagem $a';
$string['prune'] = 'Interromper';
$string['prunedpost'] = 'Foi criada uma nova discusso com esta mensagem inicial';
$string['pruneheading'] = 'Interromper a mensagem e mover para uma nova discusso';
$string['rate'] = 'Avaliar';
$string['rating'] = 'Avaliao';
$string['ratingeveryone'] = 'Todos podem avaliar as mensagens';
$string['ratingno'] = 'Nenhuma avaliao';
$string['ratingonlyteachers'] = 'Apenas os $a podem avaliar as mensagens';
$string['ratingpublic'] = '$a podem ver as avaliaes de todos';
$string['ratingpublicnot'] = '$a podem ver apenas as suas avaliaes';
$string['ratings'] = 'Avaliaes';
$string['ratingssaved'] = 'Avaliaes gravadas';
$string['ratingsuse'] = 'Usar avaliaes';
$string['ratingtime'] = 'Permitir avaliao apenas das mensagens compreendidas neste arco de tempo:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Leia o resto deste tpico';
$string['replies'] = 'Comentrios';
$string['repliesmany'] = '$a respostas at agora';
$string['repliesone'] = '$a resposta at agora';
$string['reply'] = 'Responder';
$string['replyforum'] = 'Responder ao frum';
$string['rsssubscriberssdiscussions'] = 'Mostrar RSS de \'$a\' discusses';
$string['rsssubscriberssposts'] = 'Mostrar RSS de \'$a\' mensagens';
$string['search'] = 'Buscar';
$string['searchdatefrom'] = 'As mensagens devem ser mais recentes que esta';
$string['searchdateto'] = 'As mensagens devem ser mais antigas que esta';
$string['searchforumintro'] = 'Por favor inserir os termos para a busca em um ou mais dos seguintes campos:';
$string['searchforums'] = 'Buscar no frum';
$string['searchfullwords'] = 'Estas palavras devem ser consideradas como palavras completas';
$string['searchnotwords'] = 'Estas palavras no devem ser includas';
$string['searcholderposts'] = 'Buscar nas mensagens mais antigas...';
$string['searchphrase'] = 'Esta frase exata deve fazer parte da mensagem';
$string['searchresults'] = 'Resultados da busca';
$string['searchsubject'] = 'Estas palavras devem fazer parte do ttulo';
$string['searchuser'] = 'Este nome deve corresponder ao autor';
$string['searchuserid'] = 'ID do autor';
$string['searchwhichforums'] = 'Escolher os fruns para a busca';
$string['searchwords'] = 'Estas palavras podem ser contidas em qualquer lugar da mensagem';
$string['seeallposts'] = 'Ver todas as mensagens criadas por este usurio';
$string['sendinratings'] = 'Enviar as minhas avaliaes recentes';
$string['showsubscribers'] = 'Mostrar assinantes';
$string['singleforum'] = 'Uma nica discusso simples';
$string['startedby'] = 'Autor';
$string['subject'] = 'Assunto';
$string['subscribe'] = 'Receber as mensagens via email';
$string['subscribeall'] = 'Inscrever todos os participantes neste frum';
$string['subscribed'] = 'Assinante';
$string['subscribenone'] = 'Cancelar inscrio de todos os participantes deste frum';
$string['subscribers'] = 'Assinantes';
$string['subscribersto'] = 'Assinantes de \'$a\'';
$string['subscribestart'] = 'Me mande cpias das mensagens deste frum via Email';
$string['subscribestop'] = 'No quero receber cpias das mensagens deste frum via email';
$string['subscription'] = 'Assinatura';
$string['subscriptions'] = 'Assinaturas';
$string['trackforum'] = 'Monitorar mensagens no lidas';
$string['tracking'] = 'Monitorar';
$string['trackingoff'] = 'Desativar';
$string['trackingon'] = 'Ativar';
$string['trackingoptional'] = 'Opcional';
$string['trackingtype'] = 'Monitorar a leitura deste frum?';
$string['unread'] = 'No lida';
$string['unreadposts'] = 'Mensagens no lidas';
$string['unreadpostsnumber'] = '$a mensagens no lidas';
$string['unreadpostsone'] = '1 mensagem no lida';
$string['unsubscribe'] = 'Suspender o recebimento de mensagens deste frum via email';
$string['unsubscribed'] = 'Cancelado o recebimento de cpias das mensagens via email ';
$string['unsubscribeshort'] = 'Cancelar assinatura';
$string['yesforever'] = 'Sim, para sempre';
$string['yesinitially'] = 'Sim, inicialmente';
$string['youratedthis'] = 'Voc avaliou este';
$string['yournewtopic'] = 'Novo tpico de discusso';
$string['yourreply'] = 'A sua resposta';

?>
